/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
const boardsData = [
  { id: 1, title: 'Open', value: 1 },
  { id: 2, title: 'Backlog', value: 2 },
  { id: 3, title: 'QA / Testing', value: 3 },
  { id: 4, title: 'Pre-release', value: 4 },
  { id: 5, title: 'Production', value: 5 },
  { id: 6, title: 'Closed', value: 6 }
]

export { boardsData }
